@@ -122,7 +122,7 @@ class ProjectManager(QObject):
 
         fallback = [Encoding(["Non Return To Zero (NRZ)"]),
 
-                    Encoding(["Non Return To Zero Inverted (NRZ-I)",
+                    Encoding(["Non Return To Zero + Invert",
                               settings.DECODING_INVERT]),
 
                     Encoding(["Manchester I",
